@@ -92,6 +92,17 @@ get_provider_group (GoaProvider *_provider)
   return GOA_PROVIDER_GROUP_BRANDED;
 }
 
+static GoaProviderFeatures
+get_provider_features (GoaProvider *_provider)
+{
+  return GOA_PROVIDER_FEATURE_BRANDED |
+         GOA_PROVIDER_FEATURE_MAIL |
+         GOA_PROVIDER_FEATURE_CALENDAR |
+         GOA_PROVIDER_FEATURE_CONTACTS |
+         GOA_PROVIDER_FEATURE_CHAT |
+         GOA_PROVIDER_FEATURE_DOCUMENTS;
+}
+
 static const gchar *
 get_authorization_uri (GoaOAuth2Provider *provider)
 {
@@ -253,7 +264,26 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 static gboolean
 is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
 {
-  return FALSE;
+  WebKitDOMHTMLElement *element;
+  gboolean ret;
+  gchar *id;
+
+  id = NULL;
+  ret = FALSE;
+
+  if (!WEBKIT_DOM_IS_HTML_BUTTON_ELEMENT (node))
+    goto out;
+
+  element = WEBKIT_DOM_HTML_ELEMENT (node);
+  id = webkit_dom_html_element_get_id (element);
+  if (g_strcmp0 (id, "submit_deny_access") != 0)
+    goto out;
+
+  ret = TRUE;
+
+ out:
+  g_free (id);
+  return ret;
 }
 
 static gboolean
@@ -409,7 +439,6 @@ build_object (GoaProvider         *provider,
                         "smtp-supported",  TRUE,
                         "smtp-host",       "smtp.gmail.com",
                         "smtp-user-name",  email_address,
-                        "smtp-use-auth",   TRUE,
                         "smtp-use-tls",    TRUE,
                         NULL);
           goa_object_skeleton_set_mail (object, mail);
@@ -711,6 +740,7 @@ goa_google_provider_class_init (GoaGoogleProviderClass *klass)
   provider_class->get_provider_type          = get_provider_type;
   provider_class->get_provider_name          = get_provider_name;
   provider_class->get_provider_group         = get_provider_group;
+  provider_class->get_provider_features      = get_provider_features;
   provider_class->build_object               = build_object;
   provider_class->ensure_credentials_sync    = ensure_credentials_sync;
   provider_class->show_account               = show_account;
