@@ -88,6 +88,12 @@ get_provider_group (GoaProvider *provider)
   return GOA_PROVIDER_GROUP_MAIL;
 }
 
+static GoaProviderFeatures
+get_provider_features (GoaProvider *_provider)
+{
+  return GOA_PROVIDER_FEATURE_MAIL;
+}
+
 static GIcon *
 get_provider_icon (GoaProvider *provider, GoaObject *object)
 {
@@ -669,7 +675,6 @@ create_account_details_ui (GoaProvider    *provider,
 
   data->cluebar_label = gtk_label_new ("");
   gtk_label_set_line_wrap (GTK_LABEL (data->cluebar_label), TRUE);
-  gtk_label_set_max_width_chars (GTK_LABEL (data->cluebar_label), 36);
   gtk_container_add (GTK_CONTAINER (gtk_info_bar_get_content_area (GTK_INFO_BAR (data->cluebar))),
                      data->cluebar_label);
 
@@ -1569,6 +1574,7 @@ goa_imap_smtp_provider_class_init (GoaImapSmtpProviderClass *klass)
   provider_class->get_provider_type          = get_provider_type;
   provider_class->get_provider_name          = get_provider_name;
   provider_class->get_provider_group         = get_provider_group;
+  provider_class->get_provider_features      = get_provider_features;
   provider_class->get_provider_icon          = get_provider_icon;
   provider_class->add_account                = add_account;
   provider_class->refresh_account            = refresh_account;
