@@ -93,6 +93,12 @@ get_provider_group (GoaProvider *_provider)
   return GOA_PROVIDER_GROUP_TICKETING;
 }
 
+static GoaProviderFeatures
+get_provider_features (GoaProvider *_provider)
+{
+  return GOA_PROVIDER_FEATURE_TICKETING;
+}
+
 typedef struct
 {
   GtkDialog *dialog;
@@ -578,15 +584,12 @@ on_object_manager_ensured_for_look_up (GoaKerberosProvider *self,
   const char         *identifier;
   GList              *objects, *node;
   GError             *error;
-  gboolean            found;
 
   error = NULL;
-  found = FALSE;
 
   if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
                                              &error))
     {
-
       g_simple_async_result_take_error (operation_result, error);
       g_simple_async_result_complete_in_idle (operation_result);
       g_object_unref (operation_result);
@@ -626,16 +629,12 @@ on_object_manager_ensured_for_look_up (GoaKerberosProvider *self,
                                                      candidate_identity,
                                                      (GDestroyNotify)
                                                      g_object_unref);
-          found = TRUE;
           break;
         }
 
       g_object_unref (candidate_identity);
     }
 
-  if (!found)
-    g_simple_async_result_set_error (operation_result, GOA_ERROR, GOA_ERROR_FAILED, "Failed to find an identity");
-
   g_list_free_full (objects, (GDestroyNotify) g_object_unref);
   g_simple_async_result_complete_in_idle (G_SIMPLE_ASYNC_RESULT (operation_result));
   g_object_unref (operation_result);
@@ -1889,11 +1888,7 @@ ensure_credentials_sync (GoaProvider    *provider,
   if (g_simple_async_result_propagate_error (operation_result, &lookup_error))
     {
       translate_error (&lookup_error);
-      g_set_error_literal (error,
-                           GOA_ERROR,
-                           GOA_ERROR_NOT_AUTHORIZED,
-                           lookup_error->message);
-      g_error_free (lookup_error);
+      g_propagate_error (error, lookup_error);
       g_object_unref (operation_result);
       return FALSE;
     }
@@ -1933,6 +1928,7 @@ goa_kerberos_provider_class_init (GoaKerberosProviderClass *kerberos_class)
   provider_class->get_provider_type          = get_provider_type;
   provider_class->get_provider_name          = get_provider_name;
   provider_class->get_provider_group         = get_provider_group;
+  provider_class->get_provider_features      = get_provider_features;
   provider_class->build_object               = build_object;
   provider_class->add_account                = add_account;
   provider_class->refresh_account            = refresh_account;
